# As an emulator, this should be submitted to tainted

%define uname dolphin

%define nightly 1
%if 0%{?nightly}
# Number comes from snapshot reference on dolphin-emu.org/download
# Use make-snapshot.sh to generate the tarball
# Use the latest beta snapshot version (pass commit hash to make-snapshot.sh)
# for a semblance of stability.
%define snapshot 11824
%define snaprel 1
%endif

Name:           dolphin-emu
Epoch:          1
Version:        5.0%{?snapshot:.%{snapshot}}
Release:        %mkrel 1
License:        GPLv2+
Summary:        GameCube/Wii emulator
Url:            https://dolphin-emu.org
Group:          Emulators
%if 0%{?snapshot}
Source0:        %{uname}-%{version}.tar.xz
%else
Source0:        https://github.com/dolphin-emu/dolphin/archive/%{version}/%{uname}-%{version}.tar.gz
%endif
Source1:        make-snapshot.sh

# Updated bundled soundtouch to 2.1.2, fixes 9 CVEs.
# https://github.com/dolphin-emu/dolphin/pull/8725
Patch0:         dolphin-emu-pr-8725.patch

# (akien) Upstream does not support 32-bit platforms anymore.
# They used to work, but without JIT and thus not really useful to play games.
ExclusiveArch:  x86_64 aarch64

BuildRequires:  cmake
BuildRequires:  ffmpeg-devel
BuildRequires:  libgomp-devel
BuildRequires:  liblzo-devel
BuildRequires:  mbedtls-devel
BuildRequires:  miniupnpc-devel
BuildRequires:  pugixml-devel
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(libcurl)
# Upstream is going to fork enet while trying to stay protocol compatible
# https://github.com/comex/dolphin/commit/eb234da67fef01ffbcf1ae87dce8872cbf451162
# Might want to reconsider building against the shared version in the future
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sfml-network)

# Modified upstream to use short instead of float and disable exceptions.
Provides:       bundled(soundtouch) = 2.1.2

%description
Dolphin is an emulator for two recent Nintendo video game consoles:
the GameCube and the Wii. It allows PC gamers to enjoy games for these
two consoles in full HD (1080p) with several enhancements: compatibility
with all PC controllers, turbo speed, networked multiplayer, and even more!

%prep
%autosetup -p1 -n %{uname}-%{version}

%build
%cmake -DDOLPHIN_WC_REVISION=%{!?snapshot:0}%{?snapshot:%{snapshot}} \
       -DUSE_SHARED_ENET=ON \
       -DENABLE_QT2=ON \
       -DENABLE_WX=OFF \
       -DISTRIBUTOR=%{vendor} \
       -DBUILD_SHARED_LIBS=OFF
%make_build

%install
%make_install -C build

# Thirdparty library, no need to have it installed
rm -f %{buildroot}%{_includedir}/discord_{register,rpc}.h
rm -f %{buildroot}%{_libdir}/libdiscord-rpc.a

%find_lang %{name}

%files -f %{name}.lang
%doc Readme.md
%{_bindir}/%{name}
%{_bindir}/%{name}-nogui
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}*.6*


%changelog
* Tue Apr 28 2020 akien <akien> 1:5.0.11824-1.mga7
+ Revision: 1572766
- Snapshot 5.0.11824
- Change versioning to use snapshot number in Version (same as Fedora)
- Backport PR 8725 to update bundled soundtouch, fixes 9 CVEs (mga#26555)

* Thu Apr 04 2019 daviddavid <daviddavid> 1:5.0-13.9599.1.mga7.tainted
+ Revision: 1385708
- Rebuild for mbedtls 2.16.1

* Tue Apr 02 2019 daviddavid <daviddavid> 1:5.0-12.9599.1.mga7.tainted
+ Revision: 1385165
- Qt5 Rebuild

* Wed Feb 13 2019 akien <akien> 1:5.0-11.9599.1.mga7.tainted
+ Revision: 1366604
- Drop support for 32-bit arches
- Snapshot r9599
- Snapshot 5.0+9413

* Thu Sep 20 2018 umeabot <umeabot> 1:5.0-10.7862.1.mga7.tainted
+ Revision: 1278042
- Mageia 7 Mass Rebuild

* Mon Aug 27 2018 daviddavid <daviddavid> 1:5.0-9.7862.1.mga7.tainted
+ Revision: 1254935
- rebuild for new miniupnpc 2.1

* Wed May 30 2018 akien <akien> 1:5.0-8.7862.1.mga7.tainted
+ Revision: 1233112
- Switch to new default Qt5 build, disable legacy wxWidgets
- Snapshot 7862

* Tue May 08 2018 kekepower <kekepower> 1:5.0-8.6436.1.mga7.tainted
+ Revision: 1227674
- Rebuild for new mbedtls

* Sun Apr 29 2018 daviddavid <daviddavid> 1:5.0-7.6436.1.mga7.tainted
+ Revision: 1223581
- add upstream patch to fix build with ffmpeg 4.0
- rebuild for new ffmpeg 4.0

* Fri Mar 09 2018 akien <akien> 1:5.0-6.6436.1.mga7.tainted
+ Revision: 1207601
- New dev snapshot 5.0+6436
- Build against bundled wxgtk 3.1, required but not available yet in mga7

* Wed Mar 07 2018 kekepower <kekepower> 1:5.0-6.mga7.tainted
+ Revision: 1207010
- Rebuild for new mbedtls

* Tue May 16 2017 neoclust <neoclust> 1:5.0-5.mga6.tainted
+ Revision: 1102000
- Rebuild against new miniupnpc

* Wed Mar 08 2017 akien <akien> 1:5.0-4.mga6.tainted
+ Revision: 1090269
- Rebuild for ffmpeg 3.2.4

* Mon Nov 14 2016 akien <akien> 1:5.0-3.mga6.tainted
+ Revision: 1067150
- Rebuild for new SFML 2.4.1

* Sun Oct 16 2016 pterjan <pterjan> 1:5.0-2.mga6
+ Revision: 1061083
- Enable generic build on non x86

* Sun Jul 10 2016 akien <akien> 1:5.0-1.mga6.tainted
+ Revision: 1040637
- Version 5.0 stable
- Improve conditional build to work with stable
- Better conditional for generic build
- Allow building nightly or stable based on a conditional macros

* Thu Jun 02 2016 daviddavid <daviddavid> 1:4.0.2-11.9366.2.mga6.tainted
+ Revision: 1019965
- rebuild for wxgtk3.0 built with GTK2

* Thu May 19 2016 akien <akien> 1:4.0.2-11.9366.1.mga6.tainted
+ Revision: 1017014
- Snapshot 9366
- MbedTLS support temporarily disabled (version too old in cauldron)

* Wed Mar 09 2016 luigiwalser <luigiwalser> 1:4.0.2-10.7082.5.mga6.tainted
+ Revision: 988647
- add patch to fix build with mbedtls

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1:4.0.2-10.7082.4.mga6.tainted
+ Revision: 918984
- rebuild for soundtouch

* Tue Oct 13 2015 fwang <fwang> 1:4.0.2-10.7082.3.mga6.tainted
+ Revision: 890227
- deal with new api of miniupnpc14
- rebuild for new miniupnpc

* Fri Aug 14 2015 ycantin <ycantin> 1:4.0.2-10.7082.2.mga6.tainted
+ Revision: 864760
- rebuild for new wxgtk built with wxRE_ADVANCED

* Thu Jul 23 2015 akien <akien> 1:4.0.2-10.7082.1.mga6.tainted
+ Revision: 856361
- Snapshot 7082
- Use system enet (to review later on as upstream is forking it)
- Add a patch to allow building against wxgtk3.0 with GTK+3
- Rebuild for wxgtk

* Sat Jun 27 2015 akien <akien> 1:4.0.2-9.6891.1.mga6.tainted
+ Revision: 846328
- New snapshot (r6891)
- Dolphin was relicensed from GPLv2 to GPLv2+

* Mon Feb 09 2015 akien <akien> 1:4.0.2-8.5406.2.mga5.tainted
+ Revision: 814393
- Rebuild for sfml 2.2

* Wed Feb 04 2015 akien <akien> 1:4.0.2-8.5406.1.mga5.tainted
+ Revision: 813385
- Enable generic (JIT-less) build on i586
- New dev snapshot 4.0-5406 (stable 4.0 branch)
- Compatible with SFML 2
- Use upstream desktop file and icons (drop custom icon sources)
- Build against system polarssl and libusb

* Wed Dec 17 2014 akien <akien> 1:4.0.2-7.mga5.tainted
+ Revision: 803764
- Rebuild for miniupnpc

* Sun Nov 16 2014 akien <akien> 1:4.0.2-6.mga5.tainted
+ Revision: 797624
- Rebuild for ffmpeg 2.4

* Sat Nov 08 2014 akien <akien> 1:4.0.2-5.mga5.tainted
+ Revision: 796094
- Rebuild for GLEW
- Improve description
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ luigiwalser <luigiwalser>
- rebuild for miniupnpc

* Tue Mar 11 2014 akien <akien> 1:4.0.2-1.mga5.tainted
+ Revision: 602469
- Bugfix version 4.0.2
- Needs wxgtk >= 2.9.3
- Adding shared BRs: lzo, miniupnpc, sdl2, soundtouch
- Remove dependency on the nonfree cg-devel

* Thu Oct 31 2013 tmb <tmb> 1:4.0-2.mga4.nonfree
+ Revision: 548351
- Mageia 4 rebuild

* Thu Oct 10 2013 dams <dams> 1:4.0-1.mga4.nonfree
+ Revision: 494507
- fix typo in specfile
+ neoclust <neoclust>
- New version

* Wed Jul 24 2013 sander85 <sander85> 1:3.5-5.mga4.nonfree
+ Revision: 457695
- Rebuild for new glew

* Tue Jul 16 2013 fwang <fwang> 1:3.5-4.mga4.nonfree
+ Revision: 454975
- rebuild for new ffmpeg

* Wed Jun 05 2013 fwang <fwang> 1:3.5-3.mga4.nonfree
+ Revision: 437475
- fix conflicts
- br sfml
- build sfml-network as static lib
- build static lib
- fix br on sfml
- force gomp
- new version 3.5
- use correct macro
- use system flags

* Thu Jan 17 2013 pterjan <pterjan> 1:3.0.802-2.mga4.nonfree
+ Revision: 389214
+ rebuild (emptylog)

* Fri Jan 11 2013 umeabot <umeabot> 1:3.0.802-2.mga3.nonfree
+ Revision: 349057
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 juancho <juancho> 1:3.0.802-1.mga3.nonfree
+ Revision: 343609
- imported package dolphin-emu

